# Contributing to dnscacher

Thank you for considering contributing to the `dnscacher` project! We welcome contributions from everyone.

## Getting Started

1. Fork the repository on GitHub.
2. Clone your forked repository (`git clone https://github.com/BartSte/dnscacher.git`).
3. Create a new branch (`git checkout -b my_branch_name`).
4. Make your changes.
5. Commit your changes (`git commit -am "Add some feature"`).
6. Push your changes to your forked repository (`git push origin my_branch_name`).
7. Create a pull request on GitHub.

## Code of Conduct

Please note that this project is released with a Contributor Code of Conduct. By participating in this project you agree to abide by its terms.

## Reporting Bugs

If you encounter any bugs or issues, please report them on the issue tracker at:

[Issues](https://github.com/BartSte/dnscacher/issues)

## License

By contributing to this project, you agree that your contributions will be licensed under the MIT License.


